@@ -8,6 +8,7 @@ from werkzeug.routing import Map, Rule
 
 from .context import AppContext
 from .http import HttpServerError, HttpNotFound, HttpRequest
+from .routes.api_page import ApiPage
 from .routes.router import Router
 
 # APP 实例集合
@@ -52,11 +53,12 @@ class App:
 
         self.api_prefix = api_prefix
         self.router = Router(self.context)
+        self.api_page = ApiPage(self.context)
 
         self.custom_url_map = {}
 
         self.url_map = Map([
-            Rule('/%s%s' % (api_prefix, '/' if append_slash else ''), endpoint='api_list'),
+            Rule('/%s%s' % (api_prefix, '/' if append_slash else ''), endpoint='api_page'),
             Rule('/%s/<path:entry>%s' % (api_prefix, '/' if append_slash else ''), endpoint='entry_only')
         ])
 
@@ -77,8 +79,8 @@ class App:
             adapter = self.url_map.bind_to_environ(environ)
 
             endpoint, values = adapter.match()
-            if endpoint == 'api_list':
-                response = self.router.api_list(request)
+            if endpoint == 'api_page':
+                response = self.api_page.dispatch(request)
             elif endpoint == 'entry_only':
                 response = self.router.dispatch(request, values['entry'])
             elif endpoint in self.custom_url_map:
@@ -114,7 +116,7 @@ class App:
         return SharedDataMiddleware(self.handle_wsgi_request, self.context.static_map)(
             environ, start_response)
 
-    def startup(self, host='127.0.0.1', port=9127, threaded=True, **kwargs):
+    def startup(self, host=None, port=9127, threaded=True, **kwargs):
         """
         开发时使用的服务器，一般来说，应仅用于开发
         :param host:
@@ -152,10 +154,22 @@ class App:
         if env_port is not None:
             port = int(env_port)
 
+        # 支持 空串和 * 标志
+        if host in [None, '', '*']:
+            host = '0.0.0.0'
+
         if self.context.api_page_enabled:
-            print(' * Table of APIs: http://%s:%s/%s%s' % (
-                host, port, self.api_prefix, '/' if self.context.append_slash else ''
-            ))
+            if host == '0.0.0.0':
+                from .util import utils
+                ips = utils.get_ip_list()
+            else:
+                ips = [host]
+
+            print(' * Table of APIs:')
+            for ip in ips:
+                print('\t- http://%s:%s/%s%s' % (
+                    ip, port, self.api_prefix, '/' if self.context.append_slash else ''
+                ))
 
         run_simple(host, port, self, use_debugger=debug, use_reloader=debug, threaded=threaded, **kwargs)
 
